@@ -26,15 +26,14 @@ sub new
 sub connect
 {
     my $self = shift;
-    my %p = @_;
 
     $self->{tran_count} = undef;
 
-    return if $self->{dbh} && $self->{dbh}->ping;
-
     # This database handle is stale or nonexistent, so we need to (re)connect
-    $self->disconnect;
-    $self->{dbh} = $self->_make_dbh( %p, name => $self->{schema}->name );
+    $self->disconnect if $self->{dbh};
+    $self->{dbh} = $self->_make_dbh( @_,
+                                     name => $self->{schema}->db_schema_name
+                                   );
 }
 
 sub supports_referential_integrity { 1 }
@@ -66,7 +65,7 @@ sub schemas
 
     my @schemas = ( map { if ( defined )
                           {
-                              /dbi:\w+:dbname=(\w+)/i;
+                              /dbi:\w+:dbname="?(\w+)"?/i;
                               $1 ? $1 : ();
                           }
                           else
@@ -98,7 +97,7 @@ sub create_database
     # connect to something else.  "template1" should always be there.
     my $dbh = $self->_make_dbh( @_, name => 'template1' );
 
-    eval { $dbh->do( "CREATE DATABASE " . $self->{schema}->name ); };
+    eval { $dbh->do( "CREATE DATABASE " . $dbh->quote_identifier( $self->{schema}->db_schema_name ) ); };
 
     my $e = $@;
 
@@ -118,19 +117,18 @@ sub drop_database
 
     my $dbh = $self->_make_dbh( @_, name => 'template1' );
 
-    eval { $dbh->do( "DROP DATABASE " . $self->{schema}->name ); };
+    eval { $dbh->do( "DROP DATABASE " . $dbh->quote_identifier( $self->{schema}->db_schema_name ) ); };
     my $e = $@;
 
     eval { $dbh->disconnect; };
+    $e ||= $@;
 
     Alzabo::Exception::Driver->throw( error => $e ) if $e;
-    Alzabo::Exception::Driver->throw( error => $@ ) if $@;
 }
 
-sub _make_dbh
+sub _connect_params
 {
     my $self = shift;
-
     my %p = @_;
 
     %p = validate( @_, { name => { type => SCALAR },
@@ -146,31 +144,28 @@ sub _make_dbh
                                       optional => 1 },
                          tty => { type => SCALAR | UNDEF,
                                   optional => 1 },
+                         service => { type => SCALAR | UNDEF,
+                                      optional => 1 },
+                         sslmode => { type => SCALAR | UNDEF,
+                                      optional => 1 },
+                         map { $_ => 0 } grep { /^pg_/ } keys %p,
                        } );
 
     my $dsn = "dbi:Pg:dbname=$p{name}";
-    foreach ( qw( host port options tty ) )
+    foreach ( qw( host port options tty service sslmode ) )
     {
-        $dsn .= ";$_=$p{$_}" if $p{$_};
+        $dsn .= ";$_=$p{$_}" if grep { defined && length } $p{$_};
     }
 
-    my $dbh;
-    eval
-    {
-        $dbh = DBI->connect( $dsn,
-                             $p{user},
-                             $p{password},
-                             { RaiseError => 1,
-                               AutoCommit => 1,
-                               PrintError => 0,
-                             }
-                           );
-    };
+    my %pg_keys = map { $_ => $p{$_} } grep { /^pg_/ } keys %p;
 
-    Alzabo::Exception::Driver->throw( error => $@ ) if $@;
-    Alzabo::Exception::Driver->throw( error => "Unable to connect to database\n" ) unless $dbh;
-
-    return $dbh;
+    return [ $dsn, $p{user}, $p{password},
+             { RaiseError => 1,
+               AutoCommit => 1,
+               PrintError => 0,
+               %pg_keys,
+             },
+           ];
 }
 
 sub next_sequence_number
@@ -178,7 +173,7 @@ sub next_sequence_number
     my $self = shift;
     my $col = shift;
 
-    $self->_check_dbh;
+    $self->_ensure_valid_dbh;
 
     Alzabo::Exception::Params->throw
         ( error => "This column (" . $col->name . ") is not sequenced" )
@@ -199,6 +194,9 @@ sub next_sequence_number
         $seq_name = join '___', $col->table->name, $col->name;
     }
 
+    $seq_name = $self->{dbh}->quote_identifier($seq_name)
+        if $self->{schema}->quote_identifiers;
+
     $self->{last_id} = $self->one_row( sql => "SELECT NEXTVAL('$seq_name')" );
 
     return $self->{last_id};
