@@ -4,13 +4,11 @@ use strict;
 use vars qw($VERSION $AUTOLOAD @EXPORT_OK %EXPORT_TAGS);
 
 use Alzabo::Exceptions;
+use Alzabo::Utils;
 
 use Alzabo::SQLMaker;
 use base qw(Alzabo::SQLMaker);
 
-use Params::Validate qw( :all );
-Params::Validate::validation_options( on_fail => sub { Alzabo::Exception::Params->throw( error => join '', @_ ) } );
-
 $VERSION = 2.0;
 
 my $MADE_FUNCTIONS;
@@ -49,10 +47,10 @@ sub _make_functions
 	    )
     {
 	make_function( function => $_->[0],
-		      min => 0,
-		      max => 0,
-		      groups => $_->[1]
-		    );
+                       min => 0,
+                       max => 0,
+                       groups => $_->[1]
+                     );
     }
 
     foreach ( [ RAND => [ 'math' ] ],
@@ -61,11 +59,11 @@ sub _make_functions
 	    )
     {
 	make_function( function => $_->[0],
-		      min => 0,
-		      max => 1,
-		      quote => [0],
-		      groups => $_->[1]
-		    );
+                       min => 0,
+                       max => 1,
+                       quote => [0],
+                       groups => $_->[1]
+                     );
     }
 
     make_function( function => 'CHAR',
@@ -78,11 +76,11 @@ sub _make_functions
     foreach ( [ ENCRYPT => [1,1], [ 'misc' ] ] )
     {
 	make_function( function => $_->[0],
-		      min => 0,
-		      max => 1,
-		      quote => $_->[1],
-		      groups => $_->[2],
-		    );
+                       min => 0,
+                       max => 1,
+                       quote => $_->[1],
+                       groups => $_->[2],
+                     );
     }
 
     foreach ( [ MOD => [0,0], [ 'math' ] ],
@@ -121,11 +119,11 @@ sub _make_functions
 	    )
     {
 	make_function( function => $_->[0],
-		      min => 2,
-		      max => 2,
-		      quote => $_->[1],
-		      groups => $_->[2],
-		    );
+                       min => 2,
+                       max => 2,
+                       quote => $_->[1],
+                       groups => $_->[2],
+                     );
     }
 
     foreach ( [ LEAST => [1,1,1], [ 'string' ] ],
@@ -137,11 +135,11 @@ sub _make_functions
 	    )
     {
 	make_function( function => $_->[0],
-		      min => 2,
-		      max => undef,
-		      quote => $_->[1],
-		      groups => $_->[2],
-		    );
+                       min => 2,
+                       max => undef,
+                       quote => $_->[1],
+                       groups => $_->[2],
+                     );
     }
 
     foreach ( [ LOCATE => [1,1,0], [ 'string' ] ],
@@ -157,11 +155,11 @@ sub _make_functions
 	    )
     {
 	make_function( function => $_->[0],
-		      min => 3,
-		      max => 3,
-		      quote => $_->[1],
-		      groups => $_->[2],
-		    );
+                       min => 3,
+                       max => 3,
+                       quote => $_->[1],
+                       groups => $_->[2],
+                     );
     }
 
     foreach ( [ WEEK => [1,0], [ 'datetime' ] ],
@@ -169,33 +167,33 @@ sub _make_functions
 	    )
     {
 	make_function( function => $_->[0],
-		      min => 1,
-		      max => 2,
-		      quote => $_->[1],
-		      groups => $_->[2],
-		    );
+                       min => 1,
+                       max => 2,
+                       quote => $_->[1],
+                       groups => $_->[2],
+                     );
     }
 
     make_function( function => 'CONCAT_WS',
-		  min => 3,
-		  max => undef,
-		  quote => [1,1,1,1],
-		  groups => [ 'string' ],
-		);
+                   min => 3,
+                   max => undef,
+                   quote => [1,1,1,1],
+                   groups => [ 'string' ],
+                 );
 
     make_function( function => 'EXPORT_SET',
-		  min => 3,
-		  max => 5,
-		  quote => [0,1,1,1,0],
-		  groups => [ 'string' ],
-		);
+                   min => 3,
+                   max => 5,
+                   quote => [0,1,1,1,0],
+                   groups => [ 'string' ],
+                 );
 
     make_function( function => 'INSERT',
-		  min => 3,
-		  max => 5,
-		  quote => [1,0,0,1],
-		  groups => [ 'string' ],
-		);
+                   min => 3,
+                   max => 5,
+                   quote => [1,0,0,1],
+                   groups => [ 'string' ],
+                 );
 
     foreach ( [ ABS  => [0], [ 'math' ] ],
 	      [ SIGN  => [0], [ 'math' ] ],
@@ -329,7 +327,7 @@ sub select
     #
     for ( my $i = 0; $i <= $#_; $i++ )
     {
-	if ( UNIVERSAL::isa( $_[$i], 'Alzabo::SQLMaker::Function' ) &&
+	if ( Alzabo::Utils::safe_isa( $_[$i], 'Alzabo::SQLMaker::Function' ) &&
 	     $_[$i]->as_string( $self->{driver}, $self->{quote_identifiers} ) =~ /^\s*MATCH/i )
 	{
 	    $_[$i] = $_[$i]->as_string( $self->{driver}, $self->{quote_identifiers} );
@@ -339,7 +337,7 @@ sub select
 	    splice @_, $i + 1, 1;
 
 	    if ( defined $_[ $i + 1 ] &&
-		 UNIVERSAL::isa( $_[ $i + 1 ], 'Alzabo::SQLMaker::Function' ) &&
+		 Alzabo::Utils::safe_isa( $_[ $i + 1 ], 'Alzabo::SQLMaker::Function' ) &&
 		 $_[ $i + 1 ]->as_string( $self->{driver}, $self->{quote_identifiers} ) =~
                  /^\s*IN BOOLEAN MODE/i )
 	    {
@@ -360,7 +358,7 @@ sub condition
     # Special check for [ MATCH( $foo_col, $bar_col ), AGAINST('foo bar') ]
     # IN_BOOLEAN_MODE is optional
     #
-    if ( UNIVERSAL::isa( $_[0], 'Alzabo::SQLMaker::Function' ) &&
+    if ( Alzabo::Utils::safe_isa( $_[0], 'Alzabo::SQLMaker::Function' ) &&
 	 $_[0]->as_string( $self->{driver}, $self->{quote_identifiers} ) =~ /^\s*MATCH/i )
     {
 	$self->{last_op} = 'condition';
